"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.httpServer = void 0;
const express = require("express");
const bodyParser = require("body-parser");
const routers = require("../routers/router");
const compression = require("compression");
const fallback = require("express-history-api-fallback");
const path = require("path");
const watch_1 = require("../middleware/watch");
const httpErrorHandler_1 = require("../middleware/httpErrorHandler");
class httpServer {
    static createServer(port) {
        var httpServer = express();
        httpServer.all('*', function (req, res, next) {
            res.header('Access-Control-Allow-Origin', req.headers.origin);
            res.header("Access-Control-Allow-Headers", "X-Requested-With");
            res.header('Access-Control-Allow-Headers', 'Content-Type');
            res.header("Access-Control-Allow-Methods", "PUT,POST,GET,DELETE,OPTIONS");
            res.header('Access-Control-Allow-Credentials', true);
            res.header("X-Powered-By", ' 3.2.1');
            if (req.method === 'OPTIONS') {
                res.statusCode = 200;
                res.end();
            }
            else {
                next();
            }
        });
        httpServer.use(bodyParser.json({ limit: "10kb" }));
        httpServer.use(compression());
        httpServer.use(watch_1.watch);
        routers.setRouter(httpServer);
        httpServer.use(httpErrorHandler_1.httpErrorHandler);
        httpServer.use(express.static(path.join(__dirname, "../../img/")));
        const root = path.join(__dirname, "../../public/");
        httpServer.use(express.static(root));
        httpServer.use(fallback('index.html', { root }));
        console.log('web listen on port:' + port);
        httpServer.listen(port);
        console.log('server listen on port:' + port);
        return httpServer;
    }
}
exports.httpServer = httpServer;
//# sourceMappingURL=http_server.js.map